#!/bin/sh
# DESCRIPTION: ce fichier regroupe les variables propres à la VM

readonly PATH=$PATH:/usr/sbin:/sbin
readonly vm_domainname="heureux-cyclage.org"
readonly vm_hostname="ateliers"
readonly vm_fqdn="$vm_hostname.$vm_domainname"
readonly vm=$vm_hostname
readonly vm_host="rouf.grenode.net"
readonly vm_host_nameserver="91.216.110.110"

readonly vm_use_lvm="yes"
 # - sans LVM :
 #   - on a accès au LVM de l'hôte, mais c'est pas très propre.
 #   - pour l'extension de mémoire, on peut soit :
 #       1.1.   étendre avec lvresize /dev/domU/$vm_fqdn-disk
 #       1.2.   étendre avec sfdisk $vm_dev_disk_home
 #       1.3.   étendre avec resize2fs /dev/mapper/${vm_lvm_lv}_home_deciphered
 #     soit :
 #       2.1. créer une nouvelle partition sur le LVM de l'hôte
 #       2.2. l'ajouter comme un disque supplémentaire dans /etc/xen/$vm_fqdn.cfg
 #       2.3. le monter sur /home2 en pensant à changer DHOME=/home2 dans /etc/adduser.conf
 #   - pour la sauvegarde: on peut soit :
 #     1. sauvegarder au niveau applicatif (pgdump, mysqldump, etckeeper, git)
 #     2. sauvegarder incrémentalement avec (duplicity, backup-ninja, BackupPC),
 #        depuis l'hôte pour avoir un snapshot LVM.
 # - avec LVM :
 #   - question ouverte de la performance du LVM dans du LVM.
 #   - pour l'extension de mémoire, on peut soit :
 #       1.1.   étendre avec lvresize /dev/domU/$vm_fqdn-disk
 #       1.1.   étendre avec pvextend $vm_lvm_pv
 #       1.1.   étendre avec lvresize  /dev/${vm_lvm_vg}/${vm_lvm_lv}_home
 #       1.3.   étendre avec resize2fs /dev/mapper/${vm_lvm_lv}_home_deciphered
 #   - pour la sauvegarde: on peut soit :
 #     1. sauvegarder au niveau applicatif (pgdump, mysqldump, etckeeper, git)
 #     2. sauvegarder incrémentalement avec (duplicity, backup-ninja, BackupPC),
 #        depuis la VM pour avoir un snapshot LVM.

# Cartographie de la mémoire morte :
#   SATA2 * 2 (/dev/sd{a,b})
#     /dev/sda -> /dev/sda{1,2,3}
#     /dev/sdb -> /dev/sdb{1,2,3}
#   RAID1 logiciel
#     /dev/sd{a,b}1 -> /dev/md0
#     /dev/sd{a,b}2 -> /dev/md1
#     /dev/sd{a,b}3 -> /dev/md2
#   LVM
#     /dev/md0 -> dom0
#     /dev/md2 -> domU -> /dev/mapper/$vm_fqdn-disk
#   LVM
#     /dev/mapper/$vm_fqdn-disk -> /dev/xvda{1,2}
#     /dev/xvda2 -> /dev/mapper/${vm_lvm_vg}-${vm_lvm_lv}_{swap,root,var,home}

case $vm_use_lvm in
 (no)
	;;
 (yes)
	readonly vm_lvm_vg=$vm_fqdn
	readonly vm_lvm_lv=$vm
	;;
 (*)
	exit 1;;
 esac

readonly vm_raid_effective_disks=1 # NOTE: RAID1 (mirroring)
	# NOTE: julm@rouf:~$ sudo pvs /dev/md2 -o+pe_start
	# 	PV         VG   Fmt  Attr PSize   PFree   1st PE
	# 	/dev/md2   domU lvm2 a-   925,64g 470,64g 192,00k <- pas adapté au TRIM SSD, mais on utilise du SATA2
readonly vm_e2fs_block_size=4096
	# NOTE: valeur standard pour un disque avec des secteurs de 512 octets :
	# julm@rouf:~$ grep . /sys/block/sd{a,b}/queue/*_block_size
	# /sys/block/sda/queue/logical_block_size:512
	# /sys/block/sda/queue/physical_block_size:512
	# /sys/block/sdb/queue/logical_block_size:512
	# /sys/block/sdb/queue/physical_block_size:512
readonly vm_e2fs_stripe_size=
	# NOTE: égal au chunk size de mdadm --detail ;
	# mais ne concerne pas RAID1 où il n'y a pas de changement de disque à effectuer,
	# et donc pas de chunk size.
readonly  vm_e2fs_stride=${vm_e2fs_stripe_size:+$((vm_e2fs_stripe_size / vm_e2fs_block_size))}
readonly  vm_e2fs_stripe_width=${vm_e2fs_stride:+$((vm_e2fs_stride * vm_raid_effective_disks))}
          vm_e2fs_extended_options=${vm_e2fs_stride:+,stride=$vm_e2fs_stride}${vm_e2fs_stripe_width:+,stripe_width=$vm_e2fs_stripe_width}

readonly vm_arch="amd64"
readonly vm_bridge="br-gresille"
readonly vm_ipv4="91.216.110.42" # NOTE: IPv4 publique assignée par Grésille
readonly vm_lsb_name="wheezy"
readonly vm_mac="00:16:3E:E5:98:42" # NOTE: addresse MAC assignée par Grésille
 # NOTE: on part sur wheezy dès le début
 # dans l'idée de ne pas s'embêter avec
 # une migration squeeze -> wheezy dans deux mois ;
 # et parce qu'on juge wheezy « suffisamment stable ».

rule_env () { # DESCRIPTION: affiche les $vm_*
	set | grep '^vm_'
 }
